@@ -18,7 +18,6 @@ NULL
 #'                        api_token = "FBHV7C")
 #'}
 #'
-#'
 #' @export
 get_account_information <- function(user_code, api_token) {
   if (missing(user_code)) {
@@ -35,16 +34,16 @@ get_account_information <- function(user_code, api_token) {
       })
 
 
-  validate_json <- jsonlite::validate(httr::content(r, "text"))[1]
+  validate_json <- jsonlite::validate(httr::content(r, "text", encoding = "UTF-8"))[1]
 
   if (validate_json == FALSE) {
     stop("Invalid user credentials.\n Please check your user code or your api token")
   }
 
-  account_info <- httr::content(r, "text")
+  account_info <- httr::content(r, "text", encoding = "UTF-8")
   account_info <- jsonlite::fromJSON(account_info)
 
-  if (pipeline$Success[1] == FALSE) {
+  if (account_info$Success[1] == FALSE) {
     stop("Invalid user credentials or pipeline ID.\n Please check your user code or your api token")
   }
 
